summaryrefslogtreecommitdiffstats
path: root/gluster
diff options
context:
space:
mode:
authorZandrr <campbellalex11@gmail.com>2015-06-27 07:21:59 +0000
committerZandrr <campbellalex11@gmail.com>2015-06-27 07:21:59 +0000
commitcd6e853a5f7c6faa26822fb7669d16ce57997744 (patch)
treef3829c9bae21acf1e4a6ce7d722669f4e8fbf212 /gluster
parent2c468ae0d5a1e25998373abb72d87b1ee7693816 (diff)
changed unmount to umount
Change-Id: Iced9bb59a33c38964e012f9d6c9ef13efc1f184c
Diffstat (limited to 'gluster')
-rwxr-xr-xgluster/gfapi.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/gluster/gfapi.py b/gluster/gfapi.py
index bd6f240..9b0d9a8 100755
--- a/gluster/gfapi.py
+++ b/gluster/gfapi.py
@@ -453,7 +453,7 @@ class Volume(object):
else:
self._mounted = True
- def unmount(self):
+ def umount(self):
"""
Unmount a mounted GlusterFS volume.
@@ -465,13 +465,13 @@ class Volume(object):
if ret < 0:
raise LibgfapiException("glfs_fini(%s) failed." % (self.fs))
else:
# Succeeded. Protect against multiple unmount() calls.
self._mounted = False
self.fs = None
def __del__(self):
try:
- self.unmount()
+ self.umount()
except LibgfapiException:
pass
@@ -465,13 +465,13 @@ class Volume(object):
raise LibgfapiException("glfs_fini(%s) failed." % (self.fs))
else:
- # Succeeded. Protect against multiple unmount() calls.
+ # Succeeded. Protect against multiple umount() calls.
self._mounted = False
self.fs = None